check_format

Function check_format 

pub fn check_format(
    globs: &[String],
    user_excludes: &[String],
) -> Result<Vec<LintelDiagnostic>>
Check formatting of files, returning diagnostics for unformatted files.

Loads lintel.toml and merges exclude patterns. Files that fail to parse are silently skipped (they will be caught by schema validation).

Errors

Returns an error if file discovery fails (e.g. invalid glob pattern or I/O error).